// AOcrayon: basedlg.cpp

#include "aocrayon.h"
#include "basedlg.h"

#include <qvariant.h>
#include <qtabwidget.h>
#include <qwidgetstack.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qgroupbox.h>
#include <qheader.h>
#include <qlistview.h>
#include <qlineedit.h>
#include <qlabel.h>
#include <qimage.h>
#include <qpixmap.h>
#include <qstring.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qmessagebox.h>
#include <qcolordialog.h>
#include <qfiledialog.h>
#include <qfile.h>
#include <qxml.h>
#include <qdom.h>

#include "AOcrayon.xpm"

/*
 *  Constructs a BaseDlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
BaseDlg::BaseDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
	: QDialog( parent, name, modal, fl )
{
	if ( !name )
	setName( "BaseDlg" );
	setIcon( QPixmap( AOcrayon_xpm ) );
	BaseDlgLayout = new QVBoxLayout( this, 6, 4, "BaseDlgLayout"); 

	TabWidget = new QTabWidget( this, "TabWidget" );
	TabWidget->setMargin( 3 );

	/*
	 * Widgetstack for keeping basic/advanced mode color editing
	 */
	ColorsTab = new QWidgetStack( this, "ColorsTab" );
	ColorsTab->setFrameStyle( QFrame::Box | QFrame::Sunken );
	ColorsTab->setLineWidth( 1 );
	TabWidget->addTab( ColorsTab, "Chat Colors" );

	/*
	 * Chat color list (basic mode)
	 */
	BasicModeTab = new QWidget( ColorsTab, "BasicModeTab" );
	BasicModeTabLayout = new QGridLayout( BasicModeTab );
	BasicModeTabLayout->setSpacing( 3 );
	BasicModeTabLayout->setMargin( 3 );

	ClanLabel = new QLabel( BasicModeTab, "ClanLabel" );
	ClanLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	ClanLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( ClanLabel, 0, 0 );

	ClanBtn = new QPushButton( BasicModeTab, "ClanBtn" );
	BasicModeTabLayout->addWidget( ClanBtn, 0, 1 );

	PGroupLabel = new QLabel( BasicModeTab, "PGroupLabel" );
	PGroupLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	PGroupLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( PGroupLabel, 1, 0 );

	PGroupBtn = new QPushButton( BasicModeTab, "PGroupBtn" );
	BasicModeTabLayout->addWidget( PGroupBtn, 1, 1 );

	TeamLabel = new QLabel( BasicModeTab, "TeamLabel" );
	TeamLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	TeamLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( TeamLabel, 2, 0 );

	TeamBtn = new QPushButton( BasicModeTab, "TeamBtn" );
	BasicModeTabLayout->addWidget( TeamBtn, 2, 1 );

	ShoppingLabel = new QLabel( BasicModeTab, "ShoppingLabel" );
	ShoppingLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	ShoppingLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( ShoppingLabel, 3, 0 );

	ShoppingBtn = new QPushButton( BasicModeTab, "ShoppingBtn" );
	BasicModeTabLayout->addWidget( ShoppingBtn, 3, 1 );

	TellLabel = new QLabel( BasicModeTab, "TellLabel" );
	TellLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	TellLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( TellLabel, 4, 0 );

	TellBtn = new QPushButton( BasicModeTab, "TellBtn" );
	BasicModeTabLayout->addWidget( TellBtn, 4, 1 );

	VicinityLabel = new QLabel( BasicModeTab, "VicinityLabel" );
	VicinityLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	VicinityLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( VicinityLabel, 5, 0 );

	VicinityBtn = new QPushButton( BasicModeTab, "VicinityBtn" );
	BasicModeTabLayout->addWidget( VicinityBtn, 5, 1 );

	WhisperLabel = new QLabel( BasicModeTab, "WhisperLabel" );
	WhisperLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	WhisperLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( WhisperLabel, 6, 0 );

	WhisperBtn = new QPushButton( BasicModeTab, "WhisperBtn" );
	BasicModeTabLayout->addWidget( WhisperBtn, 6, 1 );

	ShoutLabel = new QLabel( BasicModeTab, "ShoutLabel" );
	ShoutLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	ShoutLabel->setIndent( 5 );
	BasicModeTabLayout->addWidget( ShoutLabel, 7, 0 );

	ShoutBtn = new QPushButton( BasicModeTab, "ShoutBtn" );
	BasicModeTabLayout->addWidget( ShoutBtn, 7, 1 );

	QSpacerItem* spacer_3 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	BasicModeTabLayout->addItem( spacer_3, 8, 0 );

	BasicHelpLabel = new QLabel( BasicModeTab, "BasicHelpLabel" );
	BasicModeTabLayout->addMultiCellWidget( BasicHelpLabel, 9, 9, 0, 1 );

	ColorsTab->addWidget( BasicModeTab, BasicMode );

	/*
	 * Chat color list (advanced mode)
	 */
	AdvModeTab = new QWidget( ColorsTab, "AdvModeTab" );
	AdvModeTabLayout = new QVBoxLayout( AdvModeTab );
	AdvModeTabLayout->setSpacing( 3 );
	AdvModeTabLayout->setMargin( 3 );

	ColorsList = new QListView( AdvModeTab, "ColorsList" );
	ColorsList->header()->setClickEnabled( FALSE );
	ColorsList->header()->setResizeEnabled( FALSE );
	ColorsList->addColumn( "", 0 );
	ColorsList->addColumn( tr( "Color group" ), 155 );
	ColorsList->addColumn( tr( "Color" ), 70 );
	ColorsList->addColumn( "", 85 );
	ColorsList->setColumnAlignment( 3, Qt::AlignCenter );
	ColorsList->setLineWidth( 1 );
	ColorsList->setAllColumnsShowFocus( TRUE );
	ColorsList->setSorting( -1 );
	AdvModeTabLayout->addWidget( ColorsList );

	PickColorBtn = new QPushButton( AdvModeTab, "PickColorBtn" );
	PickColorBtn->setAutoDefault( FALSE );
	AdvModeTabLayout->addWidget( PickColorBtn );

	ColorsTab->addWidget( AdvModeTab, AdvancedMode );

	/*
	 * Settings
	 */

	SettingsTab = new QFrame( this, "SettingsTab" );
	SettingsTab->setFrameStyle( QFrame::Box | QFrame::Sunken );
	SettingsTab->setLineWidth( 1 );
	SettingsTabLayout = new QVBoxLayout( SettingsTab );
	SettingsTabLayout->setSpacing( 3 );
	SettingsTabLayout->setMargin( 5 );

	AOPathLayout = new QHBoxLayout;

	AOPathLabel = new QLabel( SettingsTab, "AOPathLabel" );
	AOPathLayout->addWidget( AOPathLabel );

	AOPathBox = new QLineEdit( SettingsTab, "AOPathBox" );
	AOPathLayout->addWidget( AOPathBox );

	AOPathBtn = new QPushButton( SettingsTab, "AOPathBtn" );
	AOPathLayout->addWidget( AOPathBtn );

	SettingsTabLayout->addLayout( AOPathLayout );

	AOPathErrorLabel = new QLabel( SettingsTab, "AOPathErrorLabel" );
	SettingsTabLayout->addWidget( AOPathErrorLabel );

	ReloadBtn = new QPushButton( SettingsTab, "ReloadBtn" );
	SettingsTabLayout->addWidget( ReloadBtn );

	QFrame * Hline = new QFrame( SettingsTab );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	SettingsTabLayout->addWidget( Hline );

	RestoreBtn = new QPushButton( SettingsTab, "RestoreBtn" );
	SettingsTabLayout->addWidget( RestoreBtn );

	Hline = new QFrame( SettingsTab );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	SettingsTabLayout->addWidget( Hline );

	BGColorLayout = new QHBoxLayout;

	BGColorLabel = new QLabel( SettingsTab, "BGColorLabel" );
	BGColorLabel->setIndent( 5 );
	BGColorLayout->addWidget( BGColorLabel );

	BGColorBtn = new QPushButton( SettingsTab, "BGColorBtn" );
	BGColorLayout->addWidget( BGColorBtn );

	SettingsTabLayout->addLayout( BGColorLayout );

	Hline = new QFrame( SettingsTab );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	SettingsTabLayout->addWidget( Hline );

	ModeBtn = new QCheckBox( SettingsTab, "ModeBtn" );
	SettingsTabLayout->addWidget( ModeBtn );

	QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	SettingsTabLayout->addItem( spacer );

	TabWidget->addTab( SettingsTab, "Settings" );

	/*
	 * About text
	 */
	AboutTab = new QWidget( this, "AboutTab" );
	AboutTabLayout = new QVBoxLayout( AboutTab );
	AboutTabLayout->setSpacing( 3 );
	AboutTabLayout->setMargin( 0 );

	AboutLabel = new QLabel( AboutTab, "AboutLabel" );
	AboutLabel->setFrameStyle( QFrame::Box | QFrame::Sunken );
	AboutLabel->setIndent( 5 );
	AboutTabLayout->addWidget( AboutLabel );

	TabWidget->addTab( AboutTab, "About..." );

	BaseDlgLayout->addWidget( TabWidget );

	SysLayout = new QHBoxLayout( 0, 0, 4, "SysLayout"); 

	SaveBtn = new QPushButton( this, "SaveBtn" );
	SaveBtn->setDefault( TRUE );
	SysLayout->addWidget( SaveBtn );

	QSpacerItem* spacer_2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
	SysLayout->addItem( spacer_2 );

	CloseBtn = new QPushButton( this, "CloseBtn" );
	SysLayout->addWidget( CloseBtn );

	BaseDlgLayout->addLayout( SysLayout );

	languageChange();
	resize( QSize(360, 400).expandedTo(minimumSizeHint()) );
	clearWState( WState_Polished );

	// signals and slots connections
	connect( SaveBtn, SIGNAL( clicked() ), this, SLOT( saveData() ) );
	connect( CloseBtn, SIGNAL( clicked() ), this, SLOT( accept() ) );
	connect( ClanBtn, SIGNAL( clicked() ), this, SLOT( pickClanColor() ) );
	connect( PGroupBtn, SIGNAL( clicked() ), this, SLOT( pickPGroupColor() ) );
	connect( TeamBtn, SIGNAL( clicked() ), this, SLOT( pickTeamColor() ) );
	connect( ShoppingBtn, SIGNAL( clicked() ), this, SLOT( pickShoppingColor() ) );
	connect( TellBtn, SIGNAL( clicked() ), this, SLOT( pickTellColor() ) );
	connect( VicinityBtn, SIGNAL( clicked() ), this, SLOT( pickVicinityColor() ) );
	connect( WhisperBtn, SIGNAL( clicked() ), this, SLOT( pickWhisperColor() ) );
	connect( ShoutBtn, SIGNAL( clicked() ), this, SLOT( pickShoutColor() ) );
	connect( ColorsList, SIGNAL( doubleClicked(QListViewItem*) ), this, SLOT( pickColor(QListViewItem*) ) );
	connect( PickColorBtn, SIGNAL( clicked() ), this, SLOT( pickColor() ) );
	connect( AOPathBtn, SIGNAL( clicked() ), this, SLOT( browseAOPath() ) );
	connect( AOPathBox, SIGNAL( textChanged(const QString&) ), this, SLOT( setAOPath(const QString&) ) );
	connect( ReloadBtn, SIGNAL( clicked() ), this, SLOT( loadData() ) );
	connect( RestoreBtn, SIGNAL( clicked() ), this, SLOT( restoreOriginal() ) );
	connect( BGColorBtn, SIGNAL( clicked() ), this, SLOT( pickBGColor() ) );
	connect( ModeBtn, SIGNAL( toggled(bool) ), this, SLOT( setMode(bool) ) );

	loadPrefs();
	while( AOPath.isEmpty() || !QFile::exists( AOPath + GUIPATH + COLORFILE ) )
	{
		browseAOPath();
	}
	loadData();
	setBGColor( BGColor.value() );
}

/*
 *  Destroys the object and frees any allocated resources
 */
BaseDlg::~BaseDlg()
{
	// no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void BaseDlg::languageChange()
{
	setCaption( PROGRAM " v" VERSION );
	TabWidget->setTabLabel( ColorsTab, tr( "Chat Colors" ) );
	TabWidget->setTabLabel( SettingsTab, tr( "Settings" ) );
	TabWidget->setTabLabel( AboutTab, tr( "About..." ) );

	ClanLabel->setText( tr( "<b>Guild chat :</b>" ) );
	PGroupLabel->setText( tr( "<b>Private groups :</b>" ) );
	TeamLabel->setText( tr( "<b>Team chat :</b>" ) );
	ShoppingLabel->setText( tr( "<b>Shopping channels :</b>" ) );
	TellLabel->setText( tr( "<b>Private tells :</b>" ) );
	VicinityLabel->setText( tr( "<b>Vicinity :</b>" ) );
	WhisperLabel->setText( tr( "<b>Whisper :</b>" ) );
	ShoutLabel->setText( tr( "<b>Shout :</b>" ) );

	BasicHelpLabel->setText( tr(
		"<b><u>Changing your chatcolors:</u></b><br />"
		"Change the colors you want.<br />"
		"Click <b>Save</b> to save the data.<br />"
		"Launch Anarchy Online.<br /><br />"
		"If you allready have AO running, do this to see your changes:<br />"
		"Press <b>CTRL + SHIFT + F7</b>.<br />"
		"Make the <b>Actions</b> tab active by clicking on it.<br />" /* FIXME! Get the correct tab name */
		"Click <b>Reload menus</b>."
		) );

	ColorsList->header()->setLabel( 1, tr( "Color group" ) );
	ColorsList->header()->setLabel( 2, tr( "Color" ) );
	PickColorBtn->setText( tr( "Change s&elected color" ) );
	PickColorBtn->setAccel( QKeySequence( tr( "Alt+E" ) ) );

	AOPathLabel->setText( tr( "AO Install Dir:" ) );
	AOPathBtn->setText( tr( "..." ) );
	AOPathErrorLabel->setText( tr( "<font color=red><b>Selected path is not a valid AO installation!</b></font>" ) );
	ReloadBtn->setText( tr( "Reload Chat color data" ) );
	RestoreBtn->setText( tr( "Restore Original data" ) );
	BGColorLabel->setText( tr( "Background color" ) );
	ModeBtn->setText( tr( "Advanced mode" ) );

	AboutLabel->setText( tr( 
		"<b><font size=6 color=blue><center>" PROGRAM " v" VERSION "</center></font></b>"
		"<font color=blue><center>Copyright &copy; Mawerick 2005</center></font>"
		PROGRAM " is a third-party tool that was made with the intent to help<br />"
		" players of Anarchy Online change their chat text colors easily,<br />"
		" without mucking about with complex xml file editing.<br />"
		"Get the latest version at <a href='http://www.wrongplace.net/'>http://www.wrongplace.net/</a><br /><br />"
		"<b><u>Credits:</u></b><br />"
		"Special thanks to Oofbig for suggesting the name :)<br /><br />"
		"<b><u>Color groups (advanced mode) explained:</u></b><br />"
		"* The top 15 or so groups are just definitions for standard colors.<br />"
		"\tIt's best to just leave these alone...<br />"
		"* The groups starting with <font color=red>ct_</font> are internal colors. Do as above.<br />"
		"* Groups starting with <font color=red>CC</font> are used in various dialogs and<br /> other parts of the GUI"
		"\t(i.e. <font color=red>CCNPCChatColorEmote</font>)<br />"
		"* Groups starting with <font color=red>ctch_</font> are the various chat groups.<br />"
		"\t(i.e. <font color=red>ctch_clan</font> is your guild channel etc.)"
		) );

	SaveBtn->setText( tr( "&Save" ) );
	SaveBtn->setAccel( QKeySequence( tr( "Alt+S" ) ) );
	CloseBtn->setText( tr( "&Close" ) );
	CloseBtn->setAccel( QKeySequence( tr( "Alt+C" ) ) );
}

void BaseDlg::loadPrefs()
{
	/* set default values first */
	AOPath = "";
	AdvMode = FALSE;
	BGColor.setName( PROGRAM " background" );
	BGColor.setValue( "black" );

	/* load the config file */
	QFile CfgFile( PROGRAM ".cfg" );
	qDebug( "loadPrefs(): file: %s", CfgFile.name().latin1() );
	if( CfgFile.open( IO_ReadOnly ) )
	{
		QTextStream Config( &CfgFile );
		QString Buffer;

		while( !Config.eof() )
		{
			Buffer = Config.readLine();
			qDebug( "loadPrefs(): line: %s", Buffer.latin1() );
			QStringList List( QStringList::split( " = ", Buffer ) );
			if( !List[0].compare( "AODir" ) )
			{
				qDebug( "loadPrefs(): setting AOPath to %s", List[1].latin1() );
				setAOPath( List[1] );
			}
			if( !List[0].compare( "AdvancedMode" ) )
			{
				qDebug( "loadPrefs(): setting Advanced mode to %d", List[1].toInt() );
				setMode( List[1].toInt() );
			}
			if( !List[0].compare( "BGColor" ) )
			{
				qDebug( "loadPrefs():setting BGColor to %s", List[1].latin1() );
				setBGColor( List[1] );
			}
		}
		CfgFile.close();
	}
}

void BaseDlg::savePrefs()
{
	QFile CfgFile( PROGRAM ".cfg" );
	if( CfgFile.open( IO_WriteOnly ) )
	{
		QTextStream Config( &CfgFile );
		Config << "## " PROGRAM " Configuration ##\n";
		Config << "AODir = " << AOPath << "\n";
		Config << "AdvancedMode = " << AdvMode << "\n";
		Config << "BGColor = " << BGColor.value() << "\n";
		CfgFile.close();
	}
}

void BaseDlg::browseAOPath()
{
	QString path = QFileDialog::getExistingDirectory( AOPath, this, "AOPathDlg", tr( "Select the folder where Anarchy Online is installed:" ), TRUE );
	if( !path.isEmpty() )
	{
		path.replace( "/", "\\" );
		path.replace( 0, 1, path[0].upper() );
		setAOPath( path );
	}
}

void BaseDlg::setAOPath( const QString &path )
{
	AOPath = path;
	AOPathBox->setText( path );
	if( QFile::exists( AOPath + GUIPATH + COLORFILE ) )
	{
		AOPathErrorLabel->hide();
		ReloadBtn->show();
	}
	else
	{
		AOPathErrorLabel->show();
		ReloadBtn->hide();
	}
}

void BaseDlg::setMode( bool advmode )
{
	if( advmode == TRUE )
	{
		AdvMode = TRUE;
		ColorsTab->raiseWidget( AdvancedMode );
	}
	else
	{
		AdvMode = FALSE;
		ColorsTab->raiseWidget( BasicMode );
	}
	ModeBtn->setChecked( AdvMode );
}

void BaseDlg::setBGColor( QString value )
{
	BGColor.setColor( value );
	QPixmap temp( 60, 15 );
	temp.fill( BGColor.color() );
	BGColorBtn->setPixmap( temp );
	ColorsList->viewport()->setPaletteBackgroundColor( BGColor.color() );
	ColorsList->setPaletteForegroundColor( Colors.getByName( "ctch_vicinity" ).color() );
	ClanLabel->setPaletteBackgroundColor( BGColor.color() );
	PGroupLabel->setPaletteBackgroundColor( BGColor.color() );
	TeamLabel->setPaletteBackgroundColor( BGColor.color() );
	ShoppingLabel->setPaletteBackgroundColor( BGColor.color() );
	TellLabel->setPaletteBackgroundColor( BGColor.color() );
	VicinityLabel->setPaletteBackgroundColor( BGColor.color() );
	WhisperLabel->setPaletteBackgroundColor( BGColor.color() );
	ShoutLabel->setPaletteBackgroundColor( BGColor.color() );
}

void BaseDlg::restoreOriginal()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload original data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		loadData( "TextColors.orig" );
	}
}

void BaseDlg::loadData( const QString &filename )
{
	QDomDocument xmlDoc;
	Colors.clear();
	QFile TextColors;
	if( filename == NULL )
	{
		qDebug( "loadData(): file: %s%s%s", AOPath.latin1(), GUIPATH, COLORFILE );
		TextColors.setName( AOPath + GUIPATH + COLORFILE );
	}
	else
	{
		qDebug( "loadData(): file: %s", filename.latin1() );
		TextColors.setName( filename );
	}
	if( TextColors.open( IO_ReadOnly ) )
	{
		if( xmlDoc.setContent( &TextColors ) )
		{
			QDomNodeList nodeList = xmlDoc.elementsByTagName( "HTMLColor" );
			for( int i = 0; i < (int) nodeList.count(); i++ )
			{
				AOColor color;
				QDomNode node = nodeList.item( i );
				QDomElement element = node.toElement();

				color.setName( element.attribute( "name" ) );
				color.setValue( element.attribute( "color" ) );
				Colors.append( color );
			}
		}
		TextColors.close();
	}
	updateColorList();
}

void BaseDlg::saveData()
{
	QDir GUIDir( AOPath + GUIPATH );
	QFile XmlFile( GUIDir.filePath( COLORFILE ) );
	GUIDir.remove( COLORFILE ".bak", FALSE );
	GUIDir.rename( COLORFILE, COLORFILE ".bak", FALSE );
	if( XmlFile.open( IO_WriteOnly ) )
	{
		QDomDocument doc( "" );
		QDomElement root = doc.createElement( "Root" );
		doc.appendChild( root );

		for( AOColors::iterator it = Colors.begin(); it != Colors.end(); it++ )
		{
			QDomElement tag = doc.createElement( "HTMLColor" );
			tag.setAttribute( "name", (*it).name() );
			tag.setAttribute( "color", (*it).value() );
			root.appendChild( tag );
		}

		QString xml = doc.toString( 4 );
		QTextStream stream( &XmlFile );
		stream << xml;
		XmlFile.close();
	}
}

void BaseDlg::updateColorList()
{
	ColorsList->clear();
	QListViewItem * item = 0;
	int n = 0;
	for( AOColors::iterator it = Colors.begin(); it != Colors.end(); it++, n++ )
	{
		item = new QListViewItem( ColorsList, item );
		item->setText( 0, QString( "%1" ).arg( n ) );
		item->setText( 1, (*it).name() );
		item->setText( 2, (*it).value() );

		QColor col( (QColor) (*it).color() );
		if( col.isValid() )
		{
			QPixmap *temp = new QPixmap( 75, 15 );
			temp->fill( col );
			item->setPixmap( 3, *temp );
		}
	}

	/* Update colors for basic mode */
	QPixmap temp( 60, 15 );
	AOColor color;
	color = Colors.getByName( "ctch_clan" );
	temp.fill( color.color() );
	ClanBtn->setPixmap( temp );
	ClanLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_pgroup" );
	temp.fill( color.color() );
	PGroupBtn->setPixmap( temp );
	PGroupLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_team" );
	temp.fill( color.color() );
	TeamBtn->setPixmap( temp );
	TeamLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_seekingteam" );
	temp.fill( color.color() );
	ShoppingBtn->setPixmap( temp );
	ShoppingLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_tell" );
	temp.fill( color.color() );
	TellBtn->setPixmap( temp );
	TellLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_vicinity" );
	temp.fill( color.color() );
	VicinityBtn->setPixmap( temp );
	VicinityLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_whisper" );
	temp.fill( color.color() );
	WhisperBtn->setPixmap( temp );
	WhisperLabel->setPaletteForegroundColor( color.color() );
	color = Colors.getByName( "ctch_shout" );
	temp.fill( color.color() );
	ShoutBtn->setPixmap( temp );
	ShoutLabel->setPaletteForegroundColor( color.color() );
}

void BaseDlg::pickColor( QListViewItem* item )
{
	int index = item->text(0).toInt();
	AOColor& color = Colors[index];
	QColor newColor = QColorDialog::getColor( color.color(), this );
	if( newColor.isValid() )
	{
		color.setColor( newColor );
		updateColorList();
	}
}

void BaseDlg::pickColor()
{
	if( QListViewItem * item = ColorsList->currentItem() )
	{
		pickColor( item );
	}
}

void BaseDlg::pickColor( const QString& name )
{
	AOColor& color = Colors.getByName( name );
	QColor newColor = QColorDialog::getColor( color.color(), this );
	if( newColor.isValid() )
	{
		color.setColor( newColor );
		updateColorList();
	}
}

void BaseDlg::pickClanColor()
{
	pickColor( "ctch_clan" );
}

void BaseDlg::pickPGroupColor()
{
	pickColor( "ctch_pgroup" );
}

void BaseDlg::pickTeamColor()
{
	pickColor( "ctch_team" );
}

void BaseDlg::pickShoppingColor()
{
	pickColor( "ctch_seekingteam" );
}

void BaseDlg::pickTellColor()
{
	pickColor( "ctch_tell" );
}

void BaseDlg::pickVicinityColor()
{
	pickColor( "ctch_vicinity" );
}

void BaseDlg::pickWhisperColor()
{
	pickColor( "ctch_whisper" );
}

void BaseDlg::pickShoutColor()
{
	pickColor( "ctch_shout" );
}

void BaseDlg::pickBGColor()
{
	QColor newColor = QColorDialog::getColor( BGColor.color(), this );
	if( newColor.isValid() )
	{
		setBGColor( newColor.name() );
		updateColorList();
	}
}
