// AOcrayon: basedlg.h

#ifndef BASEDLG_H
#define BASEDLG_H

#include <qvariant.h>
#include <qdialog.h>
#include "aocolor.h"

class QWidgetStack;
class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QGroupBox;
class QFrame;
class QLabel;
class QListView;
class QListViewItem;
class QLineEdit;
class QPushButton;
class QCheckBox;
class QString;
class QTabWidget;

class BaseDlg : public QDialog
{
	Q_OBJECT

public:
	BaseDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
	~BaseDlg();

	void loadPrefs();
	void savePrefs();

	void updateColorList();

protected slots:
	virtual void languageChange();

	virtual void pickColor(QListViewItem*);
	virtual void pickColor(const QString&);
	virtual void pickColor();
	virtual void pickClanColor();
	virtual void pickPGroupColor();
	virtual void pickTeamColor();
	virtual void pickShoppingColor();
	virtual void pickTellColor();
	virtual void pickVicinityColor();
	virtual void pickWhisperColor();
	virtual void pickShoutColor();

	virtual void browseAOPath();
	virtual void setAOPath( const QString &path );

	virtual void setMode( bool advmode );
	virtual void setBGColor( QString value );
	virtual void pickBGColor();

	virtual void loadData( const QString &filename = NULL );
	virtual void saveData();
	virtual void restoreOriginal();

protected:
	QVBoxLayout* BaseDlgLayout;
	QTabWidget* TabWidget;
	QWidgetStack* ColorsTab;

	QWidget* BasicModeTab;
	QGridLayout* BasicModeTabLayout;
	QLabel* ClanLabel;
	QPushButton* ClanBtn;
	QLabel* PGroupLabel;
	QPushButton* PGroupBtn;
	QLabel* TeamLabel;
	QPushButton* TeamBtn;
	QLabel* ShoppingLabel;
	QPushButton* ShoppingBtn;
	QLabel* TellLabel;
	QPushButton* TellBtn;
	QLabel* VicinityLabel;
	QPushButton* VicinityBtn;
	QLabel* WhisperLabel;
	QPushButton* WhisperBtn;
	QLabel* ShoutLabel;
	QPushButton* ShoutBtn;
	QLabel* BasicHelpLabel;

	QWidget* AdvModeTab;
	QVBoxLayout* AdvModeTabLayout;
	QListView* ColorsList;
	QPushButton* PickColorBtn;

	QFrame* SettingsTab;
	QVBoxLayout* SettingsTabLayout;
	QHBoxLayout* AOPathLayout;
	QLabel* AOPathLabel;
	QLineEdit* AOPathBox;
	QPushButton* AOPathBtn;
	QLabel* AOPathErrorLabel;
	QPushButton* ReloadBtn;
	QPushButton* RestoreBtn;
	QHBoxLayout* BGColorLayout;
	QLabel* BGColorLabel;
	QPushButton* BGColorBtn;
	QCheckBox* ModeBtn;

	QWidget* AboutTab;
	QVBoxLayout* AboutTabLayout;
	QLabel* AboutLabel;

	QHBoxLayout* SysLayout;
	QPushButton* SaveBtn;
	QPushButton* CloseBtn;

	QString AOPath;
	AOColors Colors;
	AOColor BGColor;

	enum Mode{ BasicMode, AdvancedMode };

	bool AdvMode;
};

#endif // BASEDLG_H